; +--------------------------------------------------------+
; | DEFINICE KONSTANT                                      |
; +--------------------------------------------------------+

; SERVO:
; ( Poloha serva muze byt v rozsahu <75-225> )
symbol TRIM = 10
symbol LEFT = 90 - TRIM
symbol CENTER = 150 - TRIM
symbol RIGHT = 210 - TRIM
symbol SERVO_DELAY = 200

; CHAPADLO:
symbol HAND_OPEN = 160
symbol HAND_HOLD = 100

; POMOCNE NAZVY PRO A/D PREVODNIK:
symbol SERV = 3
symbol CLK = 2
symbol STROBE = 1
symbol LED = 0

; POMOCNE NNAZVY PRO VZDALENOSTI:
symbol DISTANCE_10_CM = 128
symbol DISTANCE_20_CM = 82
symbol DISTANCE_30_CM = 64



; +--------------------------------------------------------+
; | VYUZITI PROMENNYCH b0..b13                             |                                      |
; +--------------------------------------------------------+
; b0	rezervovano
; b1	vzdalenost z infradalkomeru (pomocna promenna)
; b2	vzdalenost prekazky (diskretni hodnoty 0, 1, 2, 3)
; b3	smer prekazky (diskretni hodnoty LEFT, CENTER, RIGHT)


; +--------------------------------------------------------+
; | PRIPRAVA VYSTUPNICH PORTU                              |
; +--------------------------------------------------------+
; | Poradi je zde z mnemotechnickych duvodu zprehazeno dle |
; | skutecneho poredi pinu na desce Hobbyrobot-Picaxe      |
; +--------------------------------------------------------+
	low SERV	; 3 (bily) Vystup pulsu na servo
	low CLK	; 2 (sedy) CLK pro A/D prevodnik
	high STROBE	; 1 (hnedy) STROBE pro A/D prevodnik 
	low LED	; 0 (bily) Vystup na signalizacni LED
	low 7  ;  (zeleny) H-mustek pro pravy motor
	low 6	;  (zeleny) H-mustek pro pravy motor
	low 5	; (cerveny) H-mustek pro levy motor 
	low 4	; (cerveny) H-mustek pro levy motor



b0 = CENTER
b1 = HAND_OPEN



; +--------------------------------------------------------+
; | HLAVNI SMYCKA PROGRAMU                                 |
; +--------------------------------------------------------+
; | Cil: Pruzkum terenu. Hledat prekazky, ale nenarazet    |
; | do nich                                                |
; | Strategie: |
; | Jede vpred, |
; +--------------------------------------------------------+

mainCycle:

	;servo 3,LEFT
	;wait 1		; Prodleva jedna sekunda 
	;servo 3,RIGHT
	;wait 1		; Prodleva jedna sekunda 

	if b2 > 2 then
 
	; Dalkomer kouka dopredu
		servo 3,CENTER
		pause SERVO_DELAY

	; Dalkomer prozkoumava okoli:
	else
		; HLEDA PREKAZKU VLEVO:
		servo 3,LEFT
		pause SERVO_DELAY
		gosub checkObstackle
		if b2 < 2 then
			b3 = LEFT
		endif

		; HLEDA PREKAZKU UPROSTRED:
		servo 3,CENTER
		pause SERVO_DELAY
		gosub checkObstackle
		if b2 < 2 then
			b3 = CENTER
		endif

		; HLEDA PREKAZKU VPRAVO:
		servo 3,RIGHT
		pause SERVO_DELAY
		gosub checkObstackle
		if b2 < 2 then
			b3 = RIGHT
		endif

		; OTOCENI DO STREDOVE POLOHY:
		servo 3,CENTER
		pause SERVO_DELAY
	endif


	gosub checkObstackle		; Vzdalenost se ulozi do  promenne b2
	gosub decide



	;gosub getRange

	goto mainCycle



; +--------------------------------------------------------+
; | DECIDE                                                 |
; +--------------------------------------------------------+

decide:
	if b2 = 3 then
		gosub goAhead
		goto endTest
	endif

	if b2 = 2 then
		gosub goLeft
		goto endTest
	endif

	if b2 = 1 then
		gosub turnRight
		goto endTest
	endif

	gosub goBack		; Pripad, ze je prekazka nejblize

endTest:
	return



; +--------------------------------------------------------+
; | VPRED                                                  |
; +--------------------------------------------------------+
; | Levy motor : A                                         |
; | Pravy motor: B                                         |
; +--------------------------------------------------------+

goAhead:
	;forward A
	;forward B
	gosub motorLeft_ahead
	gosub motorRight_ahead
	return



; +--------------------------------------------------------+
; | VZAD                                                  |
; +--------------------------------------------------------+
goBack:
	gosub motorLeft_back
	gosub motorRight_back
	return



; +--------------------------------------------------------+
; | VLEVO OBLOUKEM                                         |
; +--------------------------------------------------------+
goLeft:
	; LEVY MOTOR STOP:
	low 4
	low 5
	; PRAVY MOTOR VPRED:
	high 6
	low 7
	return



; +--------------------------------------------------------+
; | VPRAVO NA MISTE                                        |
; +--------------------------------------------------------+
turnRight:
	; LEVY MOTOR VPRED:
	low 4
	high 5
	gosub motorRight_back
	; PRAVY MOTOR VZAD:
	low 6
	high 7
	return



; +--------------------------------------------------------+
; | OVLADANI LEVEHO MOTORU                                 |
; +--------------------------------------------------------+

; LEVY MOTOR STOP:
motorLeft_stop:
	low 4
	low 5
	return

; LEVY MOTOR VPRED:
motorLeft_ahead:
	low 4
	high 5
	return

; LEVY MOTOR VZAD:
motorLeft_back:
	high 4
	low 5
	return



; +--------------------------------------------------------+
; | OVLADANI PRAVEHO MOTORU                                |
; +--------------------------------------------------------+

; PRAVY MOTOR STOP:
motorRight_stop:
	low 6
	low 7
	return

; PRAVY MOTOR VPRED:
motorRight_ahead:
	high 6
	low 7
	return

; PRAVY MOTOR VZAD:
motorRight_back:
	low 6
	high 7
	return



; +--------------------------------------------------------+
; | INFRADALKOMER                                          |
; +--------------------------------------------------------+
; | Zmeri vzdalenost a vysledek ulozi do promenne b1,      |
; | ktera nespojite nabyva tachto hodnot:                  |
; | 0: vzdalenost mene nez 10 cm                           |
; | 1: vzdalenost v intervalu 10-20 cm                     |
; | 2: vzdalenost b intervalu 20-27 cm                     |
; | 3: vzdalenost vice nez 27 cm                           |
; | Hranice intervalu jsou ponekud "fuzzy", takze se       |
; | nezabyvame jejich otevrenosti ci uzavrenosti           | 
; +--------------------------------------------------------+

checkObstackle:
	readadc 0, b1			; Precte napeti na dalkomeru
                    			; a prevede ho na byte

	if b1 < 64 then		; > 27 cm
		b2 = 3;40
		low LED
	else
	if b1 < 82 then		; 20-27 cm
		b2 = 2;30
		high LED
	else
	if b1 < 128 then		; 10-20 cm 
		b2 = 1;20
		low LED
	else
		b2 = 0;10	
		high LED		; 0-10 cm
	endif
	endif
	endif

	return


